@@ -7,10 +7,12 @@ Extends the functionality of the #dataclass module to provide additional metadat
 import types
 import textwrap
 from dataclasses import dataclass as _dataclass, field as _field, Field as _Field, _MISSING_TYPE
-from typing import Any, Dict, Iterable, List, Optional, Union, T, Tuple, Type, get_type_hints
+from typing import Any, Dict, Iterable, List, Optional, Union, Tuple, Type, TypeVar, get_type_hints
 from ._typing import type_repr
 from ._union import UnionResolver, StaticUnionResolver
 
+T = TypeVar('T')
+
 __all__ = [
   'UnionMetadata',
   'ModelMetadata',
@@ -30,28 +32,25 @@ def _extract_dataclass_from_kwargs(dataclass: Type[T], kwargs: Dict[str, Any]) -
   dictionary *kwargs* and returns an instance of *dataclass*.
   """
 
-  return dataclass(**{
+  return dataclass(**{  # type: ignore
     field.name: kwargs.pop(field.name)
-    for field in dataclass.__dataclass_fields__.values()
+    for field in dataclass.__dataclass_fields__.values()  # type: ignore
     if field.name in kwargs
   })
 
 
 def _field_has_default(field: _Field) -> bool:
-  return any(not isinstance(x, _MISSING_TYPE) for x in (field.default, field.default_factory))
+  return any(not isinstance(x, _MISSING_TYPE) for x in (field.default, field.default_factory))  # type: ignore
 
 
 def _field_get_default(field: _Field) -> Any:
-  if not isinstance(field.default, _MISSING_TYPE):
+  if not isinstance(field.default, _MISSING_TYPE):  # type: ignore
     return field.default
-  if not isinstance(field.default_factory, _MISSING_TYPE):
-    return field.default_factory()
+  if not isinstance(field.default_factory, _MISSING_TYPE):  # type: ignore
+    return field.default_factory()  # type: ignore
   raise RuntimeError('{!r} has no default'.format(field))
 
 
-class UnionResolver: pass
-
-
 @_dataclass
 class BaseMetadata:
   #: Use strict deserialization mode where that is not already the default.
@@ -217,7 +216,7 @@ def enumerate_fields(data_model: Union[T, Type[T]]) -> Iterable[_EnumeratedField
     data_model = type(data_model)
 
   type_hints = get_type_hints(data_model)
-  for field in data_model.__dataclass_fields__.values():
+  for field in data_model.__dataclass_fields__.values():  # type: ignore
     yield _EnumeratedField(field, field.name, type_hints[field.name], FieldMetadata.for_field(field))
 
 
@@ -235,7 +234,7 @@ class UnionMetadata(BaseMetadata):
   container: bool = _field(default=False)
 
   #: The type field of the union container.
-  type_field: str = _field(default=None)
+  type_field: Optional[str] = _field(default=None)
 
   #: The key in the data structure that identifies the union type. Defaults to "type".
   type_key: str = _field(default='type')
@@ -247,7 +246,7 @@ class UnionMetadata(BaseMetadata):
 
 
 def uniontype(
-  resolver: Union[UnionMetadata, Dict[str, Type], Type] = None,
+  resolver: Union[UnionResolver, Dict[str, Type], Type] = None,
   container: bool = False,
   type_field: str = None,
   **kwargs
@@ -310,12 +309,14 @@ def uniontype(
         setattr(cls, key, scope[key])
 
     def _make_property(type_name: str, annotation: Any) -> property:
-      def getter(self) -> annotation:
+      def getter(self) -> annotation:  # type: ignore
+        assert type_field is not None
         has_type = getattr(self, type_field)
         if has_type != type_name:
           raise TypeError(f'{type_repr(cls)}.{type_name} cannot be accessed if {type_field} == {has_type!r}')
         return self._value
-      def setter(self, value: annotation) -> None:
+      def setter(self, value: annotation) -> None:  # type: ignore
+        assert type_field is not None
         setattr(self, type_field, type_name)
         self._value = value
       return property(getter, setter)
