@@ -3,6 +3,8 @@
 Utilities for type hints not provided by the #typing module.
 """
 
+import types
+
 __all__ = [
   'type_repr',
 ]
@@ -22,6 +24,6 @@ def _type_repr(obj):
 
 
 try:
-  from typing import _type_repr as type_repr
+  from typing import _type_repr as type_repr  # type: ignore
 except ImportError:
   type_repr = _type_repr
